<div align="center"><p>
    <h1>CYBERONIX</h1>
    <img style="filter: brightness(200%)" src="https://user-images.githubusercontent.com/122822828/216810369-34904b5a-d063-48a9-a87d-11caf293243b.png" width="50%"><br>
    <img src="https://forthebadge.com/images/badges/made-with-python.svg">
    <img src="https://forthebadge.com/images/badges/built-with-love.svg">
    <br><br>
    <a href="https://github.com/TeamMetaxone/Cyberonix/releases/latest">
      <img alt="Latest release" src="https://img.shields.io/github/v/release/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=C9CBFF&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/pulse">
      <img alt="Last commit" src="https://img.shields.io/github/last-commit/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=8bd5ca&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/blob/main/LICENSE">
      <img alt="License" src="https://img.shields.io/github/license/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=ee999f&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/stargazers">
      <img alt="Stars" src="https://img.shields.io/github/stars/TeamMetaxone/Cyberonix?style=for-the-badge&logo=starship&color=c69ff5&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix/issues">
      <img alt="Issues" src="https://img.shields.io/github/issues/TeamMetaxone/Cyberonix?style=for-the-badge&logo=bilibili&color=F5E0DC&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://github.com/TeamMetaxone/Cyberonix">
        <img alt="Repo Size" src="https://img.shields.io/github/repo-size/TeamMetaxone/Cyberonix?color=%23DDB6F2&label=SIZE&logo=codesandbox&style=for-the-badge&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://twitter.com/intent/follow?screen_name=niteshlike123">
      <img alt="follow on Twitter" src="https://img.shields.io/twitter/follow/niteshlike123?style=for-the-badge&logo=twitter&color=8aadf3&logoColor=D9E0EE&labelColor=302D41" />
    </a>
    <a href="https://discord.gg/aJF4rr3PdR">
      <img alt="Discord" src="https://img.shields.io/discord/1072407436348112896?style=for-the-badge&logo=starship&color=c69ff5&logoColor=D9E0EE&labelColor=302D41"/>
    </a>
  </p>
  <p align="center">
    <img src="https://stars.medv.io/TeamMetaxone/Cyberonix.svg", title="commits"/>
  </p>

<h1 align="left">Description</h1>

<p align="left">
    Cyberonix is an open source & free tool by Team Metaxone Solution. The tool at first is developed by a team of students as part of their Internship at Metaxone Solution after their Diploma in Cyber Security Training. </p>

<p align="left"> It is a complete resource hub for Cyber Security Community. Our aim is to make this tool an 1 stop solution for all the Hackers out there to get resources of various topics in Cyber Security. We will keep updating this tool & adding new & updated resources on the go.</p>

<p align="left"> Feel free to suggest any feature that you want to see in this tool, We will be happy to include that in our next update. 
</p>

    
---


</div>


# Installation

```shell script
pip install cyberonix
```

If you get Externally-Managed-Environment issue in your machine please check this blog <a href="https://technicalnavigator.in/how-to-fix-error-externally-managed-environment-in-python-kali-linux/" target="_blank">click here</a>

# Usage

```sh
cyberonix -h
```
Please find below the instructions to access the tool's help function, along with a list of all available switches:

```console
Cyberonix is a complete resource hub for Cyber Security Community. Our aim is to make this
tool an 1 stop solution for all the Hackers out there to get resources of various topics in
Cyber Security. We will keep updating this tool & adding new & updated resources on the go.

options:
  -h, --help                  how this help message and exit
  --domain DOMAIN, -D DOMAIN  Specify the domain
  --output OUTPUT, -o OUTPUT  Specify An Output File (-o path/to/location)
  --file FILE, -f FILE        Specify An Input File (-f path/to/file.txt)
  --ip IP, -ip IP             Specify IP Address

Main Arguments:
  --tools, -t                 Run Tools Function
  --cheatsheet, -c            Run Cheatsheet Function
  --news [Date], -n [Date]    Date In The Format yyyy-mm-dd

IP:
  --getip, -gip               Get Ip Of A Domain(options: --file,--domain,--output)
  --ipinfo, -ipi              Get IP Infomation(Options: --ip,--file,--output)

DNS Records:
  --dnsrecord, -dns           To Get DNS Records(options: --domain,--file,--output) and use --record to specify record name
  --record RECORD, -r RECORD  To Give Record For DNSrecord(Like: A,TXT,MX)

Screenshoting:
  --screenshot, -s            To Get Screenshot Of Websites(options: --file,--domain,--output)

ASN Record:
  --asnrecord, -asn           To Get ASN Record(Options: --ip,--file,--output)

Password Generation:
  --passwordgen, -P           To Generate Password
  --default-password-gen, -pass
                              To Generate Random Password (Recommended)(You can only use --length,--checkpassword)
  --upper, -u                 For Uppercase
  --lower, -l                 For Lowercase
  --digits, -d                For Digits
  --punctuation, -p           For Punctuation
  --length LENGTH, -L LENGTH  To Specify Length Of Password (Default=8)
  --checkpassword, -C         To Check Your Generated Password

HTTP Status:
  --http-status, -S           To Get Http Status Code Of A Domain(Options: --domain,--file,--output)

remove duplicate:
  --remove-duplicate, -rd     To Remove Dublicates From a File(Options: --file,--output)
```


# Categories
- ## Tools
    - ### Information Gathring
        - `Nmap`
        - `Maltego`
        - `Dracnmap`
        - `Red_Hawk`
        - `Th3Inspector`
        - `Hping3`
        - `Arping`
        - `Netdiscover`
        - `Wafw00f`
    - ### Vulnerability Analysis
        - `Wpscan`
        - `Wapiti`
        - `Nmap`
        - `Legion`
        - `Nikto`
    - ### Web Application Analysis
        - `Burp Suite`
        - `Owasp Zap`
        - `Nikto`
        - `Wapiti`
        - `Nessus`
        - `Dirb`
        - `Skipfish`
        - `Nuclei`
    - ### Password Attacks
        - ### Brute Force Attacks
            - `Hashcat`
            - `John The Ripper`
            - `Hydra`
            - `Johnny`
            - `Crackstatiion`
            - `cyberchef`
        - ### Dicitionary Attacks
            - `Hashcat`
            - `John The Ripper`
            - `Hydra`
            - `Medusa`
            - `Nrack`
            - `Johnny`
            - `Crackstation`
            - `Cyberchef`
        - ### Rainbow Table Attacks
            - `Rainbowcrack`
            - `Ophcrack`
        - ### Wordlist Generator
            - `Social-Engineer`
            - `Hiddeneye`
            - `R3Bu5`
            - `Zphisher`
            - `Shellphish`
            - `Gophish`
        - ### Phishing Attacks
            - `Social-Engineer`
            - `Hiddeneye`
            - `R3Bu5`
            - `Zphisher`
            - `Shellphis`
            - `Gophish`
        - ### Keylogger Attacks
            - `Zlogger`
    - ### Wireless Attacks
        - `Kismet`
        - `Wifite`
        - `Fern Wifi Cracker`
        - `Aircrack-Ng`
        - `Fluxion`
        - `Wifiphisher`
        - `Bettercap`
    - ### Exploitation Tools
        - `Metasploit`
        - `Crackmapexec`
        - `Searchsploit`
        - `Beef`
        - `Routersploit`
        - `Sqlmap`
        - `Airmitage`
        - `Commix`
    - ### Sniffing And Spoofing
        - `Wireshark`
        - `Bettercap`
        - `Tcpdump`
        - `Arpspoof`
        - `Dsniff`
        - `Scapy`
        - `Netsniff-Ng`
        - `Macchanger`
        - `Responder`
        - `Airgeddon`
        - `Sharesniffer`
        - `Wifi-Pumpkin-3`
    - ### Post Exploitation
        - ### Privilege Escalation
            - `Metasploit-Framework`
            - `Linpeas`
            - `Sudo Killer`
            - `Berrot`
            - `Linux Exploit Suggester 2`
            - `Lse`
            - `Pspy`
            - `Bashark`
            - `Linux Private-I`
        - ### Maintain Access
            - `Metasploit-Framework`
            - `Shellter`
            - `Amber`
            - `Upx`
        - ### Clearing or Removing Tracks
            - `Metasploit-Framework`
            - `Covermyass`
    - ### Pentesting And Bug-Bounty
        - ### Information Gathering
            - `Nmap`
            - `Maltego`
            - `Dracnmap`
            - `Red_Hawk`
            - `Th3Inspector`
            - `Hping3`
            - `Arping`
            - `Netdiscover`
            - `Wafw00F`
        - ### Configuration Management
            - `Dirb`
            - `gobuster`
            - `Nikto`
            - `Wfuzz`
            - `Skipfish`
            - `Dirbuster`
            - `Feroxbuster`
            - `Nmap`
            - `Httpie`
            - `Metasploit`
            - `Securityheaders`
            - `Sqlmap`
            - `Trufflehog`
            - `Gitleaks`
            - `Secretfinder`
        - ### Secure Transmission
            - ### Writeups
                - `Check Ssl Version, Algorithms, Key Length`
                - `Check For Digital Certificate Validity`
                - `Check Credentials Only Delivered Over Https`
                - `Check Session Tokens Only Delivered Over Https`
                - `Check If Http Strict Transport Security (Hsts) In Use`
        - ### Authentication
            - `User Enumeration`
            - `Authentication Bypass`
            - `Vulnerable Remember Me Functionality`
            - `Password Reset`
            - `Captcha Bypass`
            - `Autocomplete On`
            - `Multifactor Authentication`
            - `Logout Functionality`
            - `Cache Management`
            - `Default Credentials`
        - ### Session Management
            - `Owasp Zap`
            - `Burpsuite`
            - `Nikto`
            - `Nmap`
            - `Arachni`
            - `Wapiti`
            - `Nessus`
            - `Nuclei`
            - `Fiddler`
            - `Penetration Testers Framework (Ptf)`
        - ### Authorization
            - `Burpsuite`
            - `Wireshark`
            - `Owasp Zap`
            - `Nessus`
            - `Hydra`
            - `Beef`
            - `Sqlmap`
            - `Metasploit`
            - `Nmap`
            - `Penetration Testers Framework (Ptf)`
        - ### Data Validation
            - `Xss`
            - `Xxe - Xml`
            - `Html Injection`
            - `Sql Injection`
            - `Command Injection`
            - `Http Smuggling`
            - `Http Parameter Pollution`
            - `Open Redirection`
            - `Lfi`
        - ### Denial Of Service
            - `Goldeneye`
            - `Slowhttptest`
            - `Thc-Ssl-Dos`
            - `Slowloris`
        - ### Business Logic
            - ### Writeups
                - `Business Logic`
                - `Exploiting Business Logic Vulnerabilities`
                - `Web Application — Business Logic Vulnerabilities`
                - `Business Logic Flaw`
        - ### Cryptography
            - `Sslstript`
            - `Bettercap`
            - `Ettercap (Graphical Of Bettercap)`
            - `Sslyze`
            - `0-Saft`
            - `Sslscan`
            - `Ssllabs`
        - ### Risky Functionality - File Uploads
            - `Fuxploider`
            - `Fuse`
        - ### Risky Functionality - Card Payment
            - `Burpsuite`
            - `Wireshark`
            - `Owasp Zap`
            - `Nessus`
            - `Sqlmap`
            - `Fiddler`
            - `Metasploit`
            - `Nmap`
            - `Penetration Testers Framework (Ptf)`
        - ### Html 5
            - ### Writeups
                - `Web Messaging`
                - `Web Storage Sql Injection`
                - `Cors Implementation`
                - `Offline Web Application`
- ## Cheatsheets
    - `Nmap Cheatsheet` 
    -  `Maltego Cheatsheet` 
    -  `Hping3 Cheatsheet` 
    -  `Netdiscover Cheatsheet` 
    -  `Wafw00F Cheatsheet` 
    -  `Metasploit-Framework Cheatsheet`
    -  `Wireshark Cheatsheet` 
    -  `Bettercap Cheatsheet` 
    -  `Tcpdump Cheatsheet` 
    -  `Scapy Cheatsheet` 
    -  `Responder Cheatsheet` 
    -  `Airgeddon Cheatsheet` 
    -  `Wpscan Cheatsheet` 
    -  `Wapiti Cheatsheet` 
    -  `Legion Cheatsheet` 
    -  `Nikto Cheatsheet` 
    -  `Burp Suite Cheatsheet` 
    -  `Owasp Zap Cheatsheet` 
    -  `Nessus Cheatsheet` 
    -  `Dirb Cheatsheet` 
    -  `Skipfish Cheatsheet` 
    -  `Nuclei Cheatsheet` 
    -  `Wifite Cheatsheet` 
    -  `Aircrack-Ng Cheatsheet`
- ## News
    - `Date Wise`

    
# ScreenShots
![help](https://user-images.githubusercontent.com/53564887/222358670-e7b2c901-37a7-4220-a885-b31d617dc801.png)
---
![home](https://user-images.githubusercontent.com/53564887/222358728-46594e68-cb5f-431b-9ff7-21dec0303689.png)
---
![tools](https://user-images.githubusercontent.com/53564887/222358767-be62a30f-cb7e-4d29-8448-2fffe56ce358.png)
---
![bug-bounty menue](https://user-images.githubusercontent.com/53564887/222358835-d1eb1b7a-ab0d-446b-b2de-3d6d8911b606.png)

<h1 align="left">Socials</h1>

<p align="left">
<a href="https://github.com/TeamMetaxone"><img src="https://user-images.githubusercontent.com/696094/196835284-c52d4bd1-7034-439e-848b-47d4f2933dff.svg" width="64" height="64" alt="Github Logo"/></a> <img src="assets/misc/transparent.png" height="1" width="5"/> <a href="https://discord.gg/aJF4rr3PdR"><img src="https://user-images.githubusercontent.com/696094/196835282-f5c47d66-29b7-4210-9ee0-d9cdecde3559.svg" width="64" height="64" alt="Discord Logo"/></a> <img src="assets/misc/transparent.png" height="1" width="5"/> <a href="https://twitter.com/niteshlike123"><img src="https://user-images.githubusercontent.com/696094/196835281-52617611-ede6-40da-a4bc-8c5025622bbf.svg" width="64" height="64" alt="Twitter Logo"/></a> <img src="assets/misc/transparent.png" height="1" width="5"/>
</p>

<h1 align="left">Support</h1>

<p><a href="https://www.buymeacoffee.com/metaxone" target="_blank"> <img align="left" src="https://cdn.buymeacoffee.com/buttons/v2/default-yellow.png" height="50" width="210" alt="Buymeacoffee" /></a></p><br><br><br>
<p><a href="https://paypal.me/niteshsinghhacker" target="_blank"> <img align="left" src="https://raw.githubusercontent.com/andreostrovsky/donate-with-paypal/master/blue.svg" height="70" width="210" alt="Donate with paypal" /></a></p><br><br><br>
<p><a href="https://tools.apgy.in/upi/Nitesh+Singh/niteshkumar5@ybl/" target="_blank"> <img align="left" style="border-radius:8px" src="https://user-images.githubusercontent.com/122822828/216837693-3480fcd2-b4fc-40ff-94f8-c5d7d4b82ad5.png" height="50" width="210" alt="Donate with paypal" /></a></p><br><br>
<p><a href="https://razorpay.me/@technicalnavigator" target="_blank"> <img align="left" src="https://user-images.githubusercontent.com/122822828/216838288-a946ef91-f215-4286-926f-afa71d0c3760.png" height="50" width="210" alt="Donate with paypal" /></a></p><br><br>

<div align="center">
    <h1 id="Contributors">Thanks To All Contributors</h1>

<a href="https://github.com/TeamMetaxone/Cyberonix/graphs/contributors">
  <img src="https://contrib.rocks/image?repo=TeamMetaxone/Cyberonix" />
</a>
</div>
